# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot


snapshots = Snapshot()

snapshots['test_schema[createMap-all-options] 1'] = {
    'data': {
        'createMap': {
            'map': {
                'name': 'map1'
            }
        }
    }
}

snapshots['test_schema[createMap-all-options] 2'] = {
    'data': {
        'map': {
            'beams': {
                'edges': [
                ]
            },
            'datePosted': '2020-02-20',
            'mapFilePaths': {
                'edges': [
                ]
            },
            'mapper': 'pwg-pmn',
            'name': 'map1',
            'note': '- Item 1'
        }
    }
}

snapshots['test_schema[createMap-selective-options] 1'] = {
    'data': {
        'createMap': {
            'map': {
                'name': 'map1'
            }
        }
    }
}

snapshots['test_schema[createMap-selective-options] 2'] = {
    'data': {
        'map': {
            'beams': {
                'edges': [
                ]
            },
            'datePosted': None,
            'mapFilePaths': {
                'edges': [
                ]
            },
            'mapper': 'pwg-pmn',
            'name': 'map1',
            'note': None
        }
    }
}

snapshots['test_schema[createMap-error-no-name] 1'] = {
    'errors': [
        {
            'locations': [
                {
                    'column': 30,
                    'line': 3
                }
            ],
            'message': '''Argument "input" has invalid value {mapper: "pwg-pmn"}.
In field "name": Expected "String!", found null.'''
        }
    ]
}

snapshots['test_schema[createMap-error-no-name] 2'] = {
    'data': {
        'map': None
    }
}

snapshots['test_schema[updateMap-all-options] 1'] = {
    'data': {
        'updateMap': {
            'map': {
                'mapId': '1001',
                'name': 'new-name'
            }
        }
    }
}

snapshots['test_schema[updateMap-all-options] 2'] = {
    'data': {
        'map': {
            'beams': {
                'edges': [
                ]
            },
            'datePosted': '2020-02-18',
            'mapFilePaths': {
                'edges': [
                    {
                        'node': {
                            'path': 'nersc:/go/to/my/maps'
                        }
                    }
                ]
            },
            'mapper': 'pwg-xyz',
            'name': 'new-name',
            'note': '- Note 123'
        }
    }
}

snapshots['test_schema[updateMap-selective-options] 1'] = {
    'data': {
        'updateMap': {
            'map': {
                'mapId': '1001',
                'name': 'new-name'
            }
        }
    }
}

snapshots['test_schema[updateMap-selective-options] 2'] = {
    'data': {
        'map': {
            'beams': {
                'edges': [
                ]
            },
            'datePosted': '2019-02-13',
            'mapFilePaths': {
                'edges': [
                    {
                        'node': {
                            'path': 'nersc:/go/to/my/maps'
                        }
                    }
                ]
            },
            'mapper': 'pwg-xyz',
            'name': 'new-name',
            'note': '''- This is a dummy test with a lat map
- This should not depend on any beam'''
        }
    }
}

snapshots['test_schema[deleteMap] 1'] = {
    'data': {
        'deleteMap': {
            'ok': True
        }
    }
}

snapshots['test_schema[deleteMap] 2'] = {
    'data': {
        'map': None
    }
}



# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot


snapshots = Snapshot()

snapshots['test_schema[allMapsFirstTwo] 1'] = {
    'data': {
        'allMaps': {
            'edges': [
                {
                    'node': {
                        'name': 'lat20190213'
                    }
                },
                {
                    'node': {
                        'name': 'lat20200120'
                    }
                }
            ]
        }
    }
}

snapshots['test_schema[allMapsFirstTwoSort] 1'] = {
    'data': {
        'allMaps': {
            'edges': [
                {
                    'node': {
                        'name': 'lat20200201'
                    }
                },
                {
                    'node': {
                        'name': 'lat20200120'
                    }
                }
            ]
        }
    }
}

snapshots['test_schema[mapByMapID] 1'] = {
    'data': {
        'map': {
            'name': 'lat20190213'
        }
    }
}

snapshots['test_schema[mapByMapID-nonexistent] 1'] = {
    'data': {
        'map': None
    }
}

snapshots['test_schema[mapByName] 1'] = {
    'data': {
        'map': {
            'mapId': '1001'
        }
    }
}

snapshots['test_schema[beamByBeamID] 1'] = {
    'data': {
        'beam': {
            'name': '20180101'
        }
    }
}

snapshots['test_schema[beamByBeamID-nonexistent] 1'] = {
    'data': {
        'beam': None
    }
}

snapshots['test_schema[beamByName] 1'] = {
    'data': {
        'beam': {
            'beamId': '1010'
        }
    }
}

snapshots['test_schema[allSimulations] 1'] = {
    'data': {
        'allSimulations': {
            'edges': [
                {
                    'node': {
                        'name': 'xyz-s1234-20200101'
                    }
                }
            ]
        }
    }
}

snapshots['test_schema[simulationBySimulationID] 1'] = {
    'data': {
        'simulation': {
            'name': 'xyz-s1234-20200101'
        }
    }
}

snapshots['test_schema[simulationBySimulationID-nonexistent] 1'] = {
    'data': {
        'simulation': None
    }
}



from graphene import relay
from graphene_sqlalchemy import SQLAlchemyObjectType

from ..models import MapFilePath as MapFilePathModel

##__________________________________________________________________||
class MapFilePath(SQLAlchemyObjectType):
    class Meta:
        model = MapFilePathModel
        interfaces = (relay.Node, )

# class MapFilePathConnection(relay.Connection):
#     class Meta:
#         node = MapFilePath

##__________________________________________________________________||
